==> gnuradio-docs-3.10.12.0-10-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#ac71a3fe1b3074d0392bbf0ae025cd713",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7f6703c0ad752e773fff3aa90a867656",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html#a16a18c30612337692adc76769323d18e",
"classgr_1_1iio_1_1device__source.html#adbbbd5fee5d4b2b2d00d0637301b88b7",
"classgr_1_1msg__endpoint.html#a14bc4ad779b24c77c975b0f6c1b6649b",
"classgr_1_1qtgui_1_1ber__sink__b.html#abbc064f162da722fe8663090fc7b9987",
"classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51",
"classgr_1_1qtgui_1_1histogram__sink__f.html#afc05c848d11e435817f4100575362359",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6baf71669fba0c9cbe310d789ea101f",
"classgr_1_1qtgui_1_1vector__sink__f.html#abf103c04cd69da087714cb88c099d971",
"classgr_1_1soapy_1_1block.html#a4cfc22e114a2006a293577a82d3c3dbc",
"classgr_1_1trellis_1_1fsm.html#ae8cdb8948e2f148f18c7612d419b996d",
"classgr_1_1uhd_1_1rfnoc__graph.html#a55f922bbeae810da681b5db9c72624d0",
"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1aa299e9caf16a658972dccf581e3979a3",
"classpmt_1_1pmt__base.html#a97bac3d60aa2f86fece6565f34fc4648",
"classrpcserver__base.html#ad65d23a4b1e9bfec36bdb3a17df14d22",
"const__sink__c__pydoc__template_8h.html#af2e36ce06d20fb33fa8bd7c80802cd04",
"correctiq__man__pydoc__template_8h.html#ae25263aaa55042014de05a0b68435b61",
"ctrlport__probe2__s__pydoc__template_8h.html#a9b915a0b82ab1a83be3ec436cca16443",
"dir_1a92d512b86599fa15333408b8ecf939.html",
"docs_2doxygen_2pydoc__macros_8h.html",
"dvbt__convolutional__deinterleaver__pydoc__template_8h_source.html",
"eye__sink__f__pydoc__template_8h.html#a9196628537ada4d5673b0a656f776c1c",
"filterbank__vcvcf__pydoc__template_8h.html#a01d18b2dfaec197f0f2122f0273ad40f",
"form__menus__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"functions_vars.html",
"globals_func.html",
"gsm__fr__decode__ps__pydoc__template_8h.html#a976d0abafd2c1ae144e59151825566b1",
"iir__filter_8h.html",
"ldpc__encoder__pydoc__template_8h.html#aabd1056e1a2ba4670a005676293fec53",
"message__pydoc__template_8h.html#af468f0cacf017e8d2aa23cdc97822957",
"multiply__by__tag__value__cc__pydoc__template_8h_source.html",
"namespacegr_1_1blocks.html#a97dc6283d9b3634237d2eadf8acaf704",
"namespacegr_1_1dtv.html#a6a7633d61ed04d9f2d4629c46553300aa241b8f551be51e0278ac4feedc97bb50",
"namespacegr_1_1soapy.html#a94171c3c45d214803f0644d14c4bf876",
"namespacepmt.html#a116faa64b5e54219c9d14bef2fcc9c02",
"nlog10__ff__pydoc__template_8h.html#a266da295ffe0111c1dd337210c0d2474",
"packet__headergenerator__bb__pydoc__template_8h.html#ac3665b335f3d13be0234a8e87f3794bd",
"peak__detector2__fb__pydoc__template_8h.html#ac28e256fa6638c67048f53d2e3873e9c",
"phase__modulator__fc_8h.html",
"pmt__pydoc__template_8h.html#a6fb3e30c80c4f1e77e804713274ad7fb",
"polar__decoder__sc__list_8h.html",
"puncture__bb_8h_source.html",
"req__msg__source__pydoc__template_8h.html#acb043ca8957369ccda640cac31ab1383",
"rpccallbackregister__base_8h.html#a083912edd1265872708667efecd2444b",
"sink__c__pydoc__template_8h.html#a595325a6fe88a242be42d41547081db1",
"streams__to__vector__pydoc__template_8h.html#ad5b4e98ced443a10bcb7b27b42164527",
"structrpcpmtconverter_1_1to__pmt__short__f.html#a0a4b1d894a669f5ca835200846e4936e",
"tags__strobe__pydoc__template_8h.html#a92dbdd45c3850b4e9ac26c914b8e498e",
"time__sink__f__pydoc__template_8h.html#a98a283f94ba6dba67cca10238d5ff084",
"usrp__block__pydoc__template_8h.html#a5cb607392f4ffd3b0e7e3984aa84c6b3",
"waterfall__sink__c__pydoc__template_8h.html#a8dbc5d726def314ead64bbc0f4848c6e"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> gnuradio-docs-3.10.12.0-12-x86_64.pkg.tar.zst: usr/share/doc/gnuradio/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#ac71a3fe1b3074d0392bbf0ae025cd713",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7f6703c0ad752e773fff3aa90a867656",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir_3_01gr__complex_00_01i__type_00_01double_01_4.html#a16a18c30612337692adc76769323d18e",
"classgr_1_1iio_1_1device__source.html#adbbbd5fee5d4b2b2d00d0637301b88b7",
"classgr_1_1msg__endpoint.html#a14bc4ad779b24c77c975b0f6c1b6649b",
"classgr_1_1qtgui_1_1ber__sink__b.html#abbc064f162da722fe8663090fc7b9987",
"classgr_1_1qtgui_1_1freq__sink__c.html#a0187a0131152e4d60e71659079c44f51",
"classgr_1_1qtgui_1_1histogram__sink__f.html#afc05c848d11e435817f4100575362359",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#aa6baf71669fba0c9cbe310d789ea101f",
"classgr_1_1qtgui_1_1vector__sink__f.html#abf103c04cd69da087714cb88c099d971",
"classgr_1_1soapy_1_1block.html#a4cfc22e114a2006a293577a82d3c3dbc",
"classgr_1_1trellis_1_1fsm.html#ae8cdb8948e2f148f18c7612d419b996d",
"classgr_1_1uhd_1_1rfnoc__graph.html#a55f922bbeae810da681b5db9c72624d0",
"classgr_1_1vocoder_1_1codec2.html#a4fb8331472faad41468ffdd68654e6f1aa299e9caf16a658972dccf581e3979a3",
"classpmt_1_1pmt__base.html#a97bac3d60aa2f86fece6565f34fc4648",
"classrpcserver__base.html#ad65d23a4b1e9bfec36bdb3a17df14d22",
"const__sink__c__pydoc__template_8h.html#ae0576729944b6a0383539d6e7487cf34",
"correctiq__man__pydoc__template_8h.html#a75d69a36c7aba0e3e84fa0db6be4bd1b",
"ctrlport__probe2__s__pydoc__template_8h.html#a13ded297be0009253d0957121ddd7bdd",
"dir_1761c9139db6854a36bfaa3c2a786a93.html",
"divide__pydoc__template_8h.html",
"dvbt__convolutional__deinterleaver__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"eye__sink__f__pydoc__template_8h.html#a858c20f6e302a4eb093eed6dc1681427",
"filterbank__vcvcf_8h.html",
"form__menus_8h.html",
"functions_type_t.html",
"globals_enum.html",
"gsm__fr__decode__ps__pydoc__template_8h.html",
"host__buffer__copy__pydoc__template_8h_source.html",
"ldpc__encoder__pydoc__template_8h.html#a1ae2d605e53079ffbe70d6746dce9f8d",
"message__pydoc__template_8h.html#a9740fb64e7249e75ff234a7f86b168b5",
"multiply__by__tag__value__cc__pydoc__template_8h.html#a905103b31c093b0e5792adfe8f363d85",
"namespacegr_1_1blocks.html#a92d26646e5fb2da023c54f2baa887686",
"namespacegr_1_1dtv.html#a6756f8e55d0cb81f6f1d5a0ba7807bc1a97628ceecc460e53a2ed1af58aac5166",
"namespacegr_1_1soapy.html#a0d164e750f6bab5e5c7f49d2177fc6ab",
"namespacepmt.html#a0f58166fe9f449249f5de7dc7b3ab754",
"nlog10__ff_8h_source.html",
"packet__headergenerator__bb__pydoc__template_8h.html#a77643a7a28c1ef7374c3a74c8353fb5e",
"peak__detector2__fb__pydoc__template_8h.html#a8506517faa0390156214845c79824486",
"pfb__synthesizer__ccf__pydoc__template_8h.html#aaad4de24f87a752a42fdb090f5b01eff",
"pmt__pydoc__template_8h.html#a6d6e44a40181dcb4dbff82f480a80e27",
"polar__decoder__common__pydoc__template_8h_source.html",
"pull__source__pydoc__template_8h.html#afa3b3078ba3666c520e9218be84b4c40",
"req__msg__source__pydoc__template_8h.html#a59add0019e9cbd6ef2c318a12aedcd1c",
"rpcbufferedget_8h.html",
"sink__c__pydoc__template_8h.html#a0eb827f060bd9875dd5cbff632f6cdb6",
"streams__to__vector__pydoc__template_8h.html",
"structrpcpmtconverter_1_1to__pmt__short__f.html",
"tags__strobe__pydoc__template_8h.html#a4bfec3c39cb83a44e01a13d401dc4544",
"time__sink__f__pydoc__template_8h.html#a8955a83687cf8114772f692df46ba3ec",
"usrp__block__pydoc__template_8h.html#a54333908d48c9b32dd4d9da4cf1d9c32",
"waterfall__sink__c__pydoc__template_8h.html#a7c65bc82725601e2a49c69d42b3b673d"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
